GraphBasic class

Implementers

Constructors

GraphBasic({required List<NodeInput> list, required bool centred})

Properties

centred ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incomesByNodeIdMap ↔ Map<String, List<String>>
getter/setter pair
list ↔ List<NodeInput>
getter/setter pair
loopsByNodeIdMap ↔ Map<String, List<String>>
getter/setter pair
nodesMap ↔ Map<String, NodeInput>
getter/setter pair
outcomesByNodeIdMap ↔ Map<String, List<String>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectIncomesAndOutcomes() → void
getOutcomesArray(String itemId) → List<NodeInput>
incomes(String id) → List<String>
isJoin(String id) → bool
isLoopEdge(String nodeId, String outcomeId) → bool
isRoot(String id) → bool
isSplit(String id) → bool
loops(String id) → List<String>
node(String id) → NodeInput
nodeType(String id) → NodeType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outcomes(String id) → List<String>
roots() → List<NodeInput>
toString() → String
A string representation of this object.
inherited
traverseVertically(NodeInput node, Set<String> branchSet, Set<String> totalSet) → Set<String>

Operators

operator ==(Object other) → bool
The equality operator.
inherited