GraphMatrix class

Inheritance
Implementers

Constructors

GraphMatrix({required List<NodeInput> list, required bool centred})

Properties

centred ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
incomesByNodeIdMap ↔ Map<String, List<String>>
getter/setter pairinherited
list ↔ List<NodeInput>
getter/setter pairinherited
loopsByNodeIdMap ↔ Map<String, List<String>>
getter/setter pairinherited
nodesMap ↔ Map<String, NodeInput>
getter/setter pairinherited
outcomesByNodeIdMap ↔ Map<String, List<String>>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectIncomesAndOutcomes() → void
inherited
getCenterYAmongIncomes(NodeOutput item, Matrix mtx) → int
getLowestYAmongIncomes(NodeOutput item, Matrix mtx) → int
getOutcomesArray(String itemId) → List<NodeInput>
inherited
handleLoopEdges(NodeOutput item, State state) → List<LoopNode>
hasLoops(NodeOutput item) → bool
incomes(String id) → List<String>
inherited
insertJoinIncomes(NodeOutput item, State state, TraverseQueue levelQueue, bool addItemToQueue) → void
insertLoopEdges(NodeOutput item, State state, List<LoopNode> loopNodes) → void
insertNodeOnMatrix(NodeOutput item, State state, bool checkCollision) → void
insertSplitOutcomes(NodeOutput item, State state, TraverseQueue levelQueue) → void
isJoin(String id) → bool
inherited
isLoopEdge(String nodeId, String outcomeId) → bool
inherited
isRoot(String id) → bool
inherited
isSplit(String id) → bool
inherited
joinHasUnresolvedIncomes(NodeOutput item) → bool
loops(String id) → List<String>
inherited
markIncomesAsPassed(Matrix mtx, NodeOutput item) → void
node(String id) → NodeInput
inherited
nodeType(String id) → NodeType
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outcomes(String id) → List<String>
inherited
processOrSkipNodeOnMatrix(NodeOutput item, State state) → bool
resolveCurrentJoinIncomes(Matrix mtx, NodeOutput join) → void
roots() → List<NodeInput>
inherited
toString() → String
A string representation of this object.
inherited
traverseVertically(NodeInput node, Set<String> branchSet, Set<String> totalSet) → Set<String>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited