State class

Constructors

State({required Matrix mtx, required TraverseQueue queue, int x = 0, int y = 0, int iterations = 0})

Properties

hashCode → int
The hash code for this object.
no setterinherited
iterations ↔ int
getter/setter pair
mtx → Matrix
final
queue ↔ TraverseQueue
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited