FindNodeResult class

Constructors

FindNodeResult({required List<int> coords, required NodeOutput item})

Properties

coords ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
item ↔ NodeOutput
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited