Matrix class

Constructors

Matrix()

Properties

hashCode → int
The hash code for this object.
no setterinherited
orientation ↔ MatrixOrientation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s ↔ List<List<MatrixCell?>>
getter/setter pair

Methods

cellBusyForItem(NodeOutput item, int x, int y) → bool
extendHeight(int toValue) → void
extendWidth(int toValue) → void
find(bool f(NodeOutput)) → List<int>?
findNode(bool f(NodeOutput)) → FindNodeResult?
getByCoords(int x, int y) → MatrixCell?
getFreeRowForColumn(int x) → int
hasHorizontalCollision(int x, int y) → bool
hasLoopAnchorCollision(int x, int y, int toX, String id) → bool
hasVerticalCollision(int x, int y) → bool
height() → int
insert(int x, int y, NodeOutput item) → void
insertColumnBefore(int x) → void
insertRowBefore(int y) → void
isAllChildrenOnMatrix(MatrixCell cell) → bool
normalize() → Map<String, MatrixNode>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(int x, int y, MatrixCell? item) → void
rotate() → Matrix
toString() → String
A string representation of this object.
override
width() → int

Operators

operator ==(Object other) → bool
The equality operator.
inherited