MatrixCell class

Constructors

MatrixCell({NodeOutput? full, NodeOutput? start, NodeOutput? end})

Properties

all → List<NodeOutput>
no setter
displayId → String
no setter
end ↔ NodeOutput?
getter/setter pair
full ↔ NodeOutput?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFull → bool
no setter
margin → AnchorMargin?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ NodeOutput?
getter/setter pair

Methods

add(NodeOutput item) → void
getById(String id) → NodeOutput?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited