TraverseQueue class

Constructors

TraverseQueue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s ↔ List<NodeOutput>
getter/setter pair

Methods

add({String? incomeId, TraverseQueue? bufferQueue, required List<NodeInput> items}) → dynamic
drain() → TraverseQueue
find(bool f(NodeOutput)) → NodeOutput?
length() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(NodeOutput item) → dynamic
shift() → NodeOutput
some(bool f(NodeOutput)) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited