Edge class

Constructors

Edge(List<List<double>> points, MatrixNode from, MatrixNode to, EdgeArrowType arrowType)

Properties

arrowType → EdgeArrowType
final
from → MatrixNode
final
hashCode → int
The hash code for this object.
no setterinherited
points → List<List<double>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → MatrixNode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited