LoopNode class

Constructors

LoopNode({required String id, required NodeOutput node, required int x, required int y, bool isSelfLoop = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isSelfLoop ↔ bool
getter/setter pair
node ↔ NodeOutput
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ int
getter/setter pair
y ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited