MatrixNode class

Inheritance

Constructors

MatrixNode({required int x, required int y, required String id, required List<EdgeInput> next, NodeSize? size, AnchorType? anchorType, String? from, String? to, AnchorOrientation? orientation, bool isAnchor = false, AnchorMargin? anchorMargin, List<String> passedIncomes = const [], List<String> renderIncomes = const [], int? childrenOnMatrix})

Properties

anchorMargin ↔ AnchorMargin?
getter/setter pairinherited
anchors ↔ Map<AnchorMargin, NodeOutput>
getter/setter pairinherited
anchorType ↔ AnchorType?
getter/setter pairinherited
childrenOnMatrix ↔ int?
getter/setter pairinherited
from ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
unique identifier of the node.
finalinherited
isAnchor ↔ bool
getter/setter pairinherited
next → List<EdgeInput>
outcomes list for the node defined as list of EdgeInput's.
finalinherited
node ↔ NodeOutput?
getter/setter pairinherited
orientation ↔ AnchorOrientation?
getter/setter pairinherited
passedIncomes ↔ List<String>
getter/setter pairinherited
renderIncomes ↔ List<String>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → NodeSize?
NodeSize of the node to override DirectGraph.defaultCellSize .
finalinherited
to ↔ String?
getter/setter pairinherited
x → int
column index of node inside two dimensional matrix
final
y → int
row index of node inside two dimensional matrix
final

Methods

getHeight() → double?
inherited
getWidth() → double?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInput() → NodeInput
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromNodeOutput({required int x, required int y, required NodeOutput nodeOutput}) → MatrixNode