NodeOutput class

Inheritance
Implementers

Constructors

NodeOutput({required String id, required List<EdgeInput> next, NodeSize? size, AnchorType? anchorType, String? from, String? to, AnchorOrientation? orientation, bool isAnchor = false, List<String> passedIncomes = const [], List<String> renderIncomes = const [], int? childrenOnMatrix, AnchorMargin? anchorMargin})

Properties

anchorMargin ↔ AnchorMargin?
getter/setter pair
anchors ↔ Map<AnchorMargin, NodeOutput>
getter/setter pair
anchorType ↔ AnchorType?
getter/setter pair
childrenOnMatrix ↔ int?
getter/setter pair
from ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String
unique identifier of the node.
finalinherited
isAnchor ↔ bool
getter/setter pair
next → List<EdgeInput>
outcomes list for the node defined as list of EdgeInput's.
finalinherited
node ↔ NodeOutput?
getter/setter pair
orientation ↔ AnchorOrientation?
getter/setter pair
passedIncomes ↔ List<String>
getter/setter pair
renderIncomes ↔ List<String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → NodeSize?
NodeSize of the node to override DirectGraph.defaultCellSize .
finalinherited
to ↔ String?
getter/setter pair

Methods

getHeight() → double?
inherited
getWidth() → double?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited