ArcPoint class

Inheritance

Constructors

ArcPoint(Offset end, double radius, bool clockwise)

Properties

clockwise → bool
final
direction → double
The angle of this offset as radians clockwise from the positive x-axis, in the range -pi to pi, assuming positive values of the x-axis go to the right and positive values of the y-axis go down.
no setterinherited
distance → double
The magnitude of the offset.
no setterinherited
distanceSquared → double
The square of the magnitude of the offset.
no setterinherited
dx → double
The x component of the offset.
no setterinherited
dy → double
The y component of the offset.
no setterinherited
end → Offset
final
hashCode → int
The hash code for this object.
no setterinherited
isFinite → bool
Whether both components are finite (neither infinite nor NaN).
no setterinherited
isInfinite → bool
Returns true if either component is double.infinity, and false if both are finite (or negative infinity, or NaN).
no setterinherited
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(double scaleX, double scaleY) → Offset
Returns a new offset with the x component scaled by scaleX and the y component scaled by scaleY.
inherited
toString() → String
A string representation of this object.
inherited
translate(double translateX, double translateY) → Offset
Returns a new offset with translateX added to the x component and translateY added to the y component.
inherited

Operators

operator %(double operand) → Offset
Modulo (remainder) operator.
inherited
operator &(Size other) → Rect
Rectangle constructor operator.
inherited
operator *(double operand) → Offset
Multiplication operator.
inherited
operator +(Offset other) → Offset
Binary addition operator.
inherited
operator -(Offset other) → Offset
Binary subtraction operator.
inherited
operator /(double operand) → Offset
Division operator.
inherited
operator <(OffsetBase other) → bool
Less-than operator. Compares an Offset or Size to another Offset or Size, and returns true if both the horizontal and vertical values of the left-hand-side operand are smaller than the horizontal and vertical values of the right-hand-side operand respectively. Returns false otherwise.
inherited
operator <=(OffsetBase other) → bool
Less-than-or-equal-to operator. Compares an Offset or Size to another Offset or Size, and returns true if both the horizontal and vertical values of the left-hand-side operand are smaller than or equal to the horizontal and vertical values of the right-hand-side operand respectively. Returns false otherwise.
inherited
operator ==(Object other) → bool
Compares two Offsets for equality.
inherited
operator >(OffsetBase other) → bool
Greater-than operator. Compares an Offset or Size to another Offset or Size, and returns true if both the horizontal and vertical values of the left-hand-side operand are bigger than the horizontal and vertical values of the right-hand-side operand respectively. Returns false otherwise.
inherited
operator >=(OffsetBase other) → bool
Greater-than-or-equal-to operator. Compares an Offset or Size to another Offset or Size, and returns true if both the horizontal and vertical values of the left-hand-side operand are bigger than or equal to the horizontal and vertical values of the right-hand-side operand respectively. Returns false otherwise.
inherited
operator unary-() → Offset
Unary negation operator.
inherited
operator ~/(double operand) → Offset
Integer (truncating) division operator.
inherited