GraphiteRoot class

Inheritance

Constructors

GraphiteRoot({required Matrix mtx, required Size defaultCellSize, required EdgeInsets cellPadding, required double maxScale, required double minScale, required MatrixOrientation orientation, required double contactEdgesDistance, required Clip clipBehavior, OverlayBuilder? overlayBuilder, EdgeLabels? edgeLabels, GestureEdgeTapDownCallback? onEdgeTapDown, GestureEdgeTapUpCallback? onEdgeTapUp, GestureBackgroundTapCallback? onCanvasTap, GestureEdgeLongPressStartCallback? onEdgeLongPressStart, GestureEdgeLongPressEndCallback? onEdgeLongPressEnd, GestureEdgeLongPressMoveUpdateCallback? onEdgeLongPressMoveUpdate, GestureEdgeForcePressStartCallback? onEdgeForcePressStart, GestureEdgeForcePressEndCallback? onEdgeForcePressEnd, GestureEdgeForcePressPeakCallback? onEdgeForcePressPeak, GestureEdgeForcePressUpdateCallback? onEdgeForcePressUpdate, GestureEdgeTapDownCallback? onEdgeSecondaryTapDown, GestureEdgeTapUpCallback? onEdgeSecondaryTapUp, EdgeStyleBuilder? styleBuilder, GestureNodeTapDownCallback? onNodeTapDown, GestureNodeTapUpCallback? onNodeTapUp, GestureNodeLongPressStartCallback? onNodeLongPressStart, GestureNodeLongPressEndCallback? onNodeLongPressEnd, GestureNodeLongPressMoveUpdateCallback? onNodeLongPressMoveUpdate, GestureNodeForcePressStartCallback? onNodeForcePressStart, GestureNodeForcePressEndCallback? onNodeForcePressEnd, GestureNodeForcePressPeakCallback? onNodeForcePressPeak, GestureNodeForcePressUpdateCallback? onNodeForcePressUpdate, GestureNodePanStartCallback? onNodePanStart, GestureNodePanUpdateCallback? onNodePanUpdate, GestureNodePanDownCallback? onNodePanDown, GestureNodeTapDownCallback? onNodeSecondaryTapDown, GestureNodeTapUpCallback? onNodeSecondaryTapUp, NodeCellBuilder? builder, EdgePathBuilder? pathBuilder})

Properties

builder → NodeCellBuilder?
final
cellPadding → EdgeInsets
final
clipBehavior → Clip
final
contactEdgesDistance → double
final
defaultCellSize → Size
final
edgeLabels → EdgeLabels?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxScale → double
final
minScale → double
final
mtx → Matrix
final
onCanvasTap → GestureBackgroundTapCallback?
final
onEdgeForcePressEnd → GestureEdgeForcePressEndCallback?
final
onEdgeForcePressPeak → GestureEdgeForcePressEndCallback?
final
onEdgeForcePressStart → GestureEdgeForcePressEndCallback?
final
onEdgeForcePressUpdate → GestureEdgeForcePressEndCallback?
final
onEdgeLongPressEnd → GestureEdgeLongPressEndCallback?
final
onEdgeLongPressMoveUpdate → GestureEdgeLongPressMoveUpdateCallback?
final
onEdgeLongPressStart → GestureEdgeLongPressStartCallback?
final
onEdgeSecondaryTapDown → GestureEdgeTapDownCallback?
final
onEdgeSecondaryTapUp → GestureEdgeTapUpCallback?
final
onEdgeTapDown → GestureEdgeTapDownCallback?
final
onEdgeTapUp → GestureEdgeTapUpCallback?
final
onNodeForcePressEnd → GestureNodeForcePressEndCallback?
final
onNodeForcePressPeak → GestureNodeForcePressEndCallback?
final
onNodeForcePressStart → GestureNodeForcePressEndCallback?
final
onNodeForcePressUpdate → GestureNodeForcePressEndCallback?
final
onNodeLongPressEnd → GestureNodeLongPressEndCallback?
final
onNodeLongPressMoveUpdate → GestureNodeLongPressMoveUpdateCallback?
final
onNodeLongPressStart → GestureNodeLongPressStartCallback?
final
onNodePanDown → GestureNodePanDownCallback?
final
onNodePanStart → GestureNodePanStartCallback?
final
onNodePanUpdate → GestureNodePanUpdateCallback?
final
onNodeSecondaryTapDown → GestureNodeTapDownCallback?
final
onNodeSecondaryTapUp → GestureNodeTapUpCallback?
final
onNodeTapDown → GestureNodeTapDownCallback?
final
onNodeTapUp → GestureNodeTapUpCallback?
final
orientation → MatrixOrientation
final
overlayBuilder → OverlayBuilder?
final
pathBuilder → EdgePathBuilder?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleBuilder → EdgeStyleBuilder?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _GraphiteRootState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited