EdgeStyle class

Constructors

EdgeStyle({Paint? linePaint, LineStyle lineStyle = LineStyle.solid, double borderRadius = 0, double dashLength = 10, double gapLength = 5, double dotLength = 2, EdgeArrowType arrowType = EdgeArrowType.one, double tipAngle = pi * 0.1, double tipLength = 10.0})

Properties

arrowType → EdgeArrowType
the type of arrows on the edge.
final
borderRadius → double
border radius of edges angles.
final
dashLength → double
length of dash in LineStyle.dashed and LineStyle.dashDotted styles. Ignored if style is LineStyle.solid or LineStyle.dotted.
final
dotLength → double
diameter of dot in LineStyle.dotted and LineStyle.dashDotted styles. Ignored if style is LineStyle.solid or LineStyle.dashed.
final
gapLength → double
length of a gap in LineStyle.dotted, LineStyle.dashed and LineStyle.dashDotted styles. Ignored if style is LineStyle.solid.
final
hashCode → int
The hash code for this object.
no setterinherited
linePaint → Paint
Paint of edges to use in drawing.
final
lineStyle → LineStyle
LineStyle of edges to draw.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tipAngle → double
tipAngle is the angle (in radians) between each of the 2 lines making the arrow and the curve at this point. Ignored if using custom pathBuilder is set.
final
tipLength → double
is the length (in pixels) of each of the 2 lines making the arrow. Ignored if using custom pathBuilder is set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited